#!/bin/sh
#
# usage: run_segment.sh [-g globaldict] speechfile transcript 
#

## setup
# start and end silence model name
start_sil="silB"
end_sil="silE"
# julius
juliusbin=/usr/local/bin/julius
# acoustic model (PTM not work!)
hmmdefs=/somewhere/IPA99/phone_m/model/monof/mix16/gid/hmmdefs.gz
# HMMlist file (needed for triphone models)
#hmmlist=/somewhere/IPA99/phone_m/parms/logicalTri.added

# other arguments (don't remove "-palign")
args="-palign -input file"

# temporary directory
tmpdir="/var/tmp"

########################################
if [ $# -lt 2 ]; then
    echo 'usage: run_segment.sh [-g globaldict] speechfile transcript'
    exit
fi
if [ $1 = "-g" ]; then
    if [ $# -lt 4 ]; then
	echo 'usage: run_segment.sh [-g globaldict ] speechfile transcript'
	exit
    fi
    gdict=$2
    input=$3
    trans=$4
    if [ ! -f $gdict ]; then
	echo 'globaldict' $gdict 'not found'
	exit
    fi
else
    input=$1
    trans=$2
fi
if [ ! -f $trans ]; then
    echo 'transcript' $trans 'not found'
    exit
fi
if [ ! -f $input ]; then
    echo 'speech file' $input 'not found'
    exit
fi
if [ ! -x $juliusbin ]; then
    echo 'please set "juliusbin" correctly in' $0
    exit
fi
if [ ! -f $hmmdefs ]; then
    echo 'please set "hmmdefs" correctly in' $0
    exit
fi

####################
here=`dirname $0`
tmpf=$tmpdir/run_segment.$$
mk=$here/mk_seqmodel.pl
if [ x$gdict != x ]; then
    mk="$mk -g $gdict"
fi
$mk -startsil $start_sil -endsil $end_sil $trans $tmpf
if [ x$hmmlist != x ]; then
    juliusbin="$juliusbin -hlist $hmmlist"
fi
echo $input | $juliusbin -h $hmmdefs -nlr $tmpf.2gram -nrl $tmpf.3gram.rev -v $tmpf.dict $args -palign 2> /dev/null | $here/filter.pl
rm -f $tmpf.dict $tmpf.2gram $tmpf.3gram.rev
